@@ -178,7 +178,7 @@ use Module::Build::Database::PostgreSQL::Templates;
 use Module::Build::Database::Helpers qw/do_system verify_bin info debug/;
 use strict;
 use warnings;
-our $VERSION = '0.56';
+our $VERSION = '0.57';
 
 __PACKAGE__->add_property(database_options    => default => { name => "foo", schema => "bar" });
 __PACKAGE__->add_property(database_extensions => default => { postgis => 0 } );
@@ -312,7 +312,11 @@ sub _start_new_db {
 
         debug "initializing database (log: $initlog)";
 
-        do_system($Bin{Initdb}, "-D", "$dbdir", ">>", "$initlog", "2>&1") or die "could not initdb";
+        do_system($Bin{Initdb}, "-D", "$dbdir", ">>", "$initlog", "2>&1") or do {
+            my $log = '';
+            $log = file($initlog)->slurp if -e $initlog;
+            die "could not initdb ($Bin{Initdb})\n$log\n";
+        };
 
         if (my $conf_append = $self->database_options('append_to_conf')) {
             die "cannot find postgresql.conf" unless -e "$dbdir/postgresql.conf";
@@ -324,7 +328,15 @@ sub _start_new_db {
         my $pmopts = qq[-k $dbdir -h '' -p 5432];
 
         debug "# starting postgres in $dbdir";
-        do_system($Bin{Pgctl}, qq[-o "$pmopts"], "-w", "-t", 120, "-D", "$dbdir", "-l", "postmaster.log", "start") or die "could not start postgres";
+        do_system($Bin{Pgctl}, qq[-o "$pmopts"], "-w", "-t", 120, "-D", "$dbdir", "-l", "postmaster.log", "start") or do {
+            my $log;
+            if (-e "$dbdir/postmaster.log") {
+                $log = file("$dbdir/postmaster.log")->slurp;
+            } else {
+                $log = "no log file : $dbdir/postmaster.log";
+            }
+            die "could not start postgres\n$log\n ";
+        };
 
         my $domain = $dbdir.'/.s.PGSQL.5432';
         -e $domain or die "could not find $domain";
